@@ -85,6 +85,12 @@ Block 确认违规
 
     @property
     def HitFlag(self):
+        """是否命中
+0 未命中
+1 命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._HitFlag
 
     @HitFlag.setter
@@ -93,6 +99,17 @@ Block 确认违规
 
     @property
     def Label(self):
+        """命中的标签
+Porn 色情
+Polity 政治
+Illegal 违法
+Abuse 谩骂
+Terror 暴恐
+Ad 广告
+Moan 呻吟
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -101,6 +118,13 @@ Block 确认违规
 
     @property
     def Suggestion(self):
+        """审核建议，可选值：
+Pass 通过，
+Review 建议人审，
+Block 确认违规
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -109,6 +133,10 @@ Block 确认违规
 
     @property
     def Score(self):
+        """得分，0-100
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -117,6 +145,10 @@ Block 确认违规
 
     @property
     def Text(self):
+        """音频ASR文本
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Text
 
     @Text.setter
@@ -125,6 +157,10 @@ Block 确认违规
 
     @property
     def Url(self):
+        """音频片段存储URL，有效期为1天
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Url
 
     @Url.setter
@@ -133,6 +169,10 @@ Block 确认违规
 
     @property
     def Duration(self):
+        """音频时长
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Duration
 
     @Duration.setter
@@ -141,6 +181,10 @@ Block 确认违规
 
     @property
     def Extra(self):
+        """拓展字段
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Extra
 
     @Extra.setter
@@ -149,6 +193,10 @@ Block 确认违规
 
     @property
     def TextResults(self):
+        """文本审核结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of AudioResultDetailTextResult
+        """
         return self._TextResults
 
     @TextResults.setter
@@ -157,6 +205,10 @@ Block 确认违规
 
     @property
     def MoanResults(self):
+        """音频呻吟审核结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of AudioResultDetailMoanResult
+        """
         return self._MoanResults
 
     @MoanResults.setter
@@ -165,6 +217,10 @@ Block 确认违规
 
     @property
     def LanguageResults(self):
+        """音频语种检测结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of AudioResultDetailLanguageResult
+        """
         return self._LanguageResults
 
     @LanguageResults.setter
@@ -240,6 +296,10 @@ class AudioResultDetailLanguageResult(AbstractModel):
 
     @property
     def Label(self):
+        """语种
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -248,6 +308,10 @@ class AudioResultDetailLanguageResult(AbstractModel):
 
     @property
     def Score(self):
+        """得分
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -256,6 +320,10 @@ class AudioResultDetailLanguageResult(AbstractModel):
 
     @property
     def StartTime(self):
+        """开始时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: float
+        """
         return self._StartTime
 
     @StartTime.setter
@@ -264,6 +332,10 @@ class AudioResultDetailLanguageResult(AbstractModel):
 
     @property
     def EndTime(self):
+        """结束时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: float
+        """
         return self._EndTime
 
     @EndTime.setter
@@ -272,6 +344,10 @@ class AudioResultDetailLanguageResult(AbstractModel):
 
     @property
     def SubLabelCode(self):
+        """子标签码
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._SubLabelCode
 
     @SubLabelCode.setter
@@ -322,6 +398,10 @@ class AudioResultDetailMoanResult(AbstractModel):
 
     @property
     def Label(self):
+        """固定为Moan
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -330,6 +410,9 @@ class AudioResultDetailMoanResult(AbstractModel):
 
     @property
     def Score(self):
+        """分数
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -338,6 +421,9 @@ class AudioResultDetailMoanResult(AbstractModel):
 
     @property
     def StartTime(self):
+        """开始时间
+        :rtype: float
+        """
         return self._StartTime
 
     @StartTime.setter
@@ -346,6 +432,9 @@ class AudioResultDetailMoanResult(AbstractModel):
 
     @property
     def EndTime(self):
+        """结束时间
+        :rtype: float
+        """
         return self._EndTime
 
     @EndTime.setter
@@ -354,6 +443,9 @@ class AudioResultDetailMoanResult(AbstractModel):
 
     @property
     def SubLabelCode(self):
+        """子标签码
+        :rtype: str
+        """
         return self._SubLabelCode
 
     @SubLabelCode.setter
@@ -416,6 +508,10 @@ class AudioResultDetailTextResult(AbstractModel):
 
     @property
     def Label(self):
+        """标签
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -424,6 +520,10 @@ class AudioResultDetailTextResult(AbstractModel):
 
     @property
     def Keywords(self):
+        """命中的关键词
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of str
+        """
         return self._Keywords
 
     @Keywords.setter
@@ -432,6 +532,10 @@ class AudioResultDetailTextResult(AbstractModel):
 
     @property
     def LibId(self):
+        """命中的LibId
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._LibId
 
     @LibId.setter
@@ -440,6 +544,10 @@ class AudioResultDetailTextResult(AbstractModel):
 
     @property
     def LibName(self):
+        """命中的LibName
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._LibName
 
     @LibName.setter
@@ -448,6 +556,10 @@ class AudioResultDetailTextResult(AbstractModel):
 
     @property
     def Score(self):
+        """得分
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -456,6 +568,10 @@ class AudioResultDetailTextResult(AbstractModel):
 
     @property
     def LibType(self):
+        """词库类型 1 黑白库 2 自定义库
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._LibType
 
     @LibType.setter
@@ -464,6 +580,10 @@ class AudioResultDetailTextResult(AbstractModel):
 
     @property
     def Suggestion(self):
+        """审核建议
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -510,6 +630,12 @@ class AudioSegments(AbstractModel):
 
     @property
     def OffsetTime(self):
+        """截帧时间。
+点播文件：该值为相对于视频偏移时间，单位为秒，例如：0，5，10
+直播流：该值为时间戳，例如：1594650717
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._OffsetTime
 
     @OffsetTime.setter
@@ -518,6 +644,10 @@ class AudioSegments(AbstractModel):
 
     @property
     def Result(self):
+        """结果集
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: :class:`tencentcloud.vm.v20200709.models.AudioResult`
+        """
         return self._Result
 
     @Result.setter
@@ -561,6 +691,9 @@ class BucketInfo(AbstractModel):
 
     @property
     def Bucket(self):
+        """腾讯云对象存储，存储桶名称
+        :rtype: str
+        """
         return self._Bucket
 
     @Bucket.setter
@@ -569,6 +702,9 @@ class BucketInfo(AbstractModel):
 
     @property
     def Region(self):
+        """地域
+        :rtype: str
+        """
         return self._Region
 
     @Region.setter
@@ -577,6 +713,9 @@ class BucketInfo(AbstractModel):
 
     @property
     def Object(self):
+        """对象Key
+        :rtype: str
+        """
         return self._Object
 
     @Object.setter
@@ -612,6 +751,9 @@ class CancelTaskRequest(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务ID
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -645,6 +787,9 @@ class CancelTaskResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -679,6 +824,9 @@ class CreateBizConfigRequest(AbstractModel):
 
     @property
     def BizType(self):
+        """业务ID，仅限英文字母、数字和下划线（_）组成，长度不超过8位
+        :rtype: str
+        """
         return self._BizType
 
     @BizType.setter
@@ -687,6 +835,9 @@ class CreateBizConfigRequest(AbstractModel):
 
     @property
     def MediaModeration(self):
+        """审核分类信息
+        :rtype: :class:`tencentcloud.vm.v20200709.models.MediaModerationConfig`
+        """
         return self._MediaModeration
 
     @MediaModeration.setter
@@ -695,6 +846,9 @@ class CreateBizConfigRequest(AbstractModel):
 
     @property
     def BizName(self):
+        """业务名称，用于标识业务场景，长度不超过32位
+        :rtype: str
+        """
         return self._BizName
 
     @BizName.setter
@@ -703,6 +857,9 @@ class CreateBizConfigRequest(AbstractModel):
 
     @property
     def ModerationCategories(self):
+        """审核内容，可选：Polity (政治); Porn (色情); Illegal(违法);Abuse (谩骂); Terror (暴恐); Ad (广告); Custom (自定义);
+        :rtype: list of str
+        """
         return self._ModerationCategories
 
     @ModerationCategories.setter
@@ -741,6 +898,9 @@ class CreateBizConfigResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -781,6 +941,9 @@ class CreateVideoModerationTaskRequest(AbstractModel):
 
     @property
     def BizType(self):
+        """业务类型, 定义 模版策略，输出存储配置。如果没有BizType，可以先参考 【创建业务配置】接口进行创建
+        :rtype: str
+        """
         return self._BizType
 
     @BizType.setter
@@ -789,6 +952,9 @@ class CreateVideoModerationTaskRequest(AbstractModel):
 
     @property
     def Type(self):
+        """任务类型：可选VIDEO（点播视频），LIVE_VIDEO（直播视频）
+        :rtype: str
+        """
         return self._Type
 
     @Type.setter
@@ -797,6 +963,9 @@ class CreateVideoModerationTaskRequest(AbstractModel):
 
     @property
     def Tasks(self):
+        """输入的任务信息，最多可以同时创建10个任务
+        :rtype: list of TaskInput
+        """
         return self._Tasks
 
     @Tasks.setter
@@ -805,6 +974,9 @@ class CreateVideoModerationTaskRequest(AbstractModel):
 
     @property
     def Seed(self):
+        """回调签名key，具体可以查看签名文档。
+        :rtype: str
+        """
         return self._Seed
 
     @Seed.setter
@@ -813,6 +985,9 @@ class CreateVideoModerationTaskRequest(AbstractModel):
 
     @property
     def CallbackUrl(self):
+        """接收审核信息回调地址，如果设置，则审核过程中产生的违规音频片段和画面截帧发送此接口
+        :rtype: str
+        """
         return self._CallbackUrl
 
     @CallbackUrl.setter
@@ -821,6 +996,9 @@ class CreateVideoModerationTaskRequest(AbstractModel):
 
     @property
     def Priority(self):
+        """审核排队优先级。当您有多个视频审核任务排队时，可以根据这个参数控制排队优先级。用于处理插队等逻辑。默认该参数为0
+        :rtype: int
+        """
         return self._Priority
 
     @Priority.setter
@@ -868,6 +1046,10 @@ class CreateVideoModerationTaskResponse(AbstractModel):
 
     @property
     def Results(self):
+        """任务创建结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of TaskResult
+        """
         return self._Results
 
     @Results.setter
@@ -876,6 +1058,9 @@ class CreateVideoModerationTaskResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -910,6 +1095,9 @@ class DescribeTaskDetailRequest(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务ID，创建任务后返回的TaskId字段
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -918,6 +1106,9 @@ class DescribeTaskDetailRequest(AbstractModel):
 
     @property
     def ShowAllSegments(self):
+        """是否展示所有分片，默认只展示命中规则的分片
+        :rtype: bool
+        """
         return self._ShowAllSegments
 
     @ShowAllSegments.setter
@@ -1033,6 +1224,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def TaskId(self):
+        """任务Id
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -1041,6 +1236,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def DataId(self):
+        """审核时传入的数据Id
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._DataId
 
     @DataId.setter
@@ -1049,6 +1248,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def BizType(self):
+        """业务类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._BizType
 
     @BizType.setter
@@ -1057,6 +1260,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def Name(self):
+        """任务名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -1065,6 +1272,15 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def Status(self):
+        """状态，可选值：
+FINISH 已完成
+PENDING 等待中
+RUNNING 进行中
+ERROR 出错
+CANCELLED 已取消
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Status
 
     @Status.setter
@@ -1073,6 +1289,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def Type(self):
+        """类型
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Type
 
     @Type.setter
@@ -1081,6 +1301,14 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def Suggestion(self):
+        """审核建议
+可选：
+Pass 通过
+Reveiw 建议复审
+Block 确认违规
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -1089,6 +1317,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def Labels(self):
+        """审核结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of TaskLabel
+        """
         return self._Labels
 
     @Labels.setter
@@ -1097,6 +1329,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def MediaInfo(self):
+        """媒体解码信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: :class:`tencentcloud.vm.v20200709.models.MediaInfo`
+        """
         return self._MediaInfo
 
     @MediaInfo.setter
@@ -1105,6 +1341,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def InputInfo(self):
+        """任务信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: :class:`tencentcloud.vm.v20200709.models.InputInfo`
+        """
         return self._InputInfo
 
     @InputInfo.setter
@@ -1113,6 +1353,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def CreatedAt(self):
+        """创建时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._CreatedAt
 
     @CreatedAt.setter
@@ -1121,6 +1365,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def UpdatedAt(self):
+        """更新时间
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._UpdatedAt
 
     @UpdatedAt.setter
@@ -1129,6 +1377,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def TryInSeconds(self):
+        """在秒后重试
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._TryInSeconds
 
     @TryInSeconds.setter
@@ -1137,6 +1389,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def ImageSegments(self):
+        """图片结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of ImageSegments
+        """
         return self._ImageSegments
 
     @ImageSegments.setter
@@ -1145,6 +1401,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def AudioSegments(self):
+        """音频结果
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of AudioSegments
+        """
         return self._AudioSegments
 
     @AudioSegments.setter
@@ -1153,6 +1413,14 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def ErrorType(self):
+        """如果返回的状态为ERROR，该字段会标记错误类型。
+可选值：：
+DECODE_ERROR: 解码失败。（输入资源中可能包含无法解码的视频）
+URL_ERROR：下载地址验证失败。
+TIMEOUT_ERROR：处理超时。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._ErrorType
 
     @ErrorType.setter
@@ -1161,6 +1429,10 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def ErrorDescription(self):
+        """审核任务错误日志。当Error不为空时，会展示该字段
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._ErrorDescription
 
     @ErrorDescription.setter
@@ -1169,6 +1441,9 @@ TIMEOUT_ERROR：处理超时。
 
     @property
     def RequestId(self):
+        """唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -1233,6 +1508,9 @@ class DescribeVideoStatRequest(AbstractModel):
 
     @property
     def AuditType(self):
+        """审核类型 1: 机器审核; 2: 人工审核
+        :rtype: int
+        """
         return self._AuditType
 
     @AuditType.setter
@@ -1241,6 +1519,9 @@ class DescribeVideoStatRequest(AbstractModel):
 
     @property
     def Filters(self):
+        """查询条件
+        :rtype: list of Filters
+        """
         return self._Filters
 
     @Filters.setter
@@ -1289,6 +1570,9 @@ class DescribeVideoStatResponse(AbstractModel):
 
     @property
     def Overview(self):
+        """识别结果统计
+        :rtype: :class:`tencentcloud.vm.v20200709.models.Overview`
+        """
         return self._Overview
 
     @Overview.setter
@@ -1297,6 +1581,9 @@ class DescribeVideoStatResponse(AbstractModel):
 
     @property
     def TrendCount(self):
+        """识别量统计
+        :rtype: list of TrendCount
+        """
         return self._TrendCount
 
     @TrendCount.setter
@@ -1305,6 +1592,9 @@ class DescribeVideoStatResponse(AbstractModel):
 
     @property
     def EvilCount(self):
+        """违规数据分布
+        :rtype: list of EvilCount
+        """
         return self._EvilCount
 
     @EvilCount.setter
@@ -1313,6 +1603,9 @@ class DescribeVideoStatResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -1364,6 +1657,17 @@ Moan	26001
 
     @property
     def EvilType(self):
+        """违规类型：
+Terror	24001
+Porn	20002
+Polity	20001
+Ad	20105
+Abuse	20007	
+Illegal	20006	
+Spam	25001	
+Moan	26001
+        :rtype: str
+        """
         return self._EvilType
 
     @EvilType.setter
@@ -1372,6 +1676,9 @@ Moan	26001
 
     @property
     def Count(self):
+        """分布类型总量
+        :rtype: int
+        """
         return self._Count
 
     @Count.setter
@@ -1412,6 +1719,9 @@ class FileOutput(AbstractModel):
 
     @property
     def Bucket(self):
+        """存储的Bucket
+        :rtype: str
+        """
         return self._Bucket
 
     @Bucket.setter
@@ -1420,6 +1730,9 @@ class FileOutput(AbstractModel):
 
     @property
     def Region(self):
+        """Cos Region
+        :rtype: str
+        """
         return self._Region
 
     @Region.setter
@@ -1428,6 +1741,9 @@ class FileOutput(AbstractModel):
 
     @property
     def ObjectPrefix(self):
+        """对象前缀
+        :rtype: str
+        """
         return self._ObjectPrefix
 
     @ObjectPrefix.setter
@@ -1469,6 +1785,12 @@ class Filters(AbstractModel):
 
     @property
     def Name(self):
+        """查询字段：
+策略BizType
+子账号SubUin
+日期区间DateRange
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -1477,6 +1799,9 @@ class Filters(AbstractModel):
 
     @property
     def Values(self):
+        """查询值
+        :rtype: list of str
+        """
         return self._Values
 
     @Values.setter
@@ -1548,6 +1873,12 @@ Block 确认违规
 
     @property
     def HitFlag(self):
+        """违规标志
+0 未命中
+1 命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._HitFlag
 
     @HitFlag.setter
@@ -1556,6 +1887,17 @@ Block 确认违规
 
     @property
     def Label(self):
+        """命中的标签
+Porn 色情
+Sexy 性感
+Polity 政治
+Illegal 违法
+Abuse 谩骂
+Terror 暴恐
+Ad 广告
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -1564,6 +1906,13 @@ Block 确认违规
 
     @property
     def Suggestion(self):
+        """审核建议，可选值：
+Pass 通过，
+Review 建议人审，
+Block 确认违规
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -1572,6 +1921,10 @@ Block 确认违规
 
     @property
     def Score(self):
+        """得分
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -1580,6 +1933,10 @@ Block 确认违规
 
     @property
     def Results(self):
+        """画面截帧图片结果集
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of ImageResultResult
+        """
         return self._Results
 
     @Results.setter
@@ -1588,6 +1945,10 @@ Block 确认违规
 
     @property
     def Url(self):
+        """图片URL地址
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Url
 
     @Url.setter
@@ -1596,6 +1957,10 @@ Block 确认违规
 
     @property
     def Extra(self):
+        """附加字段
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Extra
 
     @Extra.setter
@@ -1685,6 +2050,17 @@ Block 确认违规
 
     @property
     def Scene(self):
+        """场景
+Porn 色情
+Sexy 性感
+Polity 政治
+Illegal 违法
+Abuse 谩骂
+Terror 暴恐
+Ad 广告
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Scene
 
     @Scene.setter
@@ -1693,6 +2069,12 @@ Block 确认违规
 
     @property
     def HitFlag(self):
+        """是否命中
+0 未命中
+1 命中
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._HitFlag
 
     @HitFlag.setter
@@ -1701,6 +2083,13 @@ Block 确认违规
 
     @property
     def Suggestion(self):
+        """审核建议，可选值：
+Pass 通过，
+Review 建议人审，
+Block 确认违规
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -1709,6 +2098,10 @@ Block 确认违规
 
     @property
     def Label(self):
+        """标签
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -1717,6 +2110,10 @@ Block 确认违规
 
     @property
     def SubLabel(self):
+        """子标签
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -1725,6 +2122,10 @@ Block 确认违规
 
     @property
     def Score(self):
+        """分数
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -1733,6 +2134,10 @@ Block 确认违规
 
     @property
     def Names(self):
+        """如果命中场景为涉政，则该数据为人物姓名列表，否则null
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of str
+        """
         return self._Names
 
     @Names.setter
@@ -1741,6 +2146,10 @@ Block 确认违规
 
     @property
     def Text(self):
+        """图片OCR文本
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Text
 
     @Text.setter
@@ -1749,6 +2158,10 @@ Block 确认违规
 
     @property
     def Details(self):
+        """其他详情
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of ImageResultsResultDetail
+        """
         return self._Details
 
     @Details.setter
@@ -1832,6 +2245,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def Name(self):
+        """任务名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -1840,6 +2257,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def Text(self):
+        """OCR识别文本
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Text
 
     @Text.setter
@@ -1848,6 +2269,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def Location(self):
+        """位置信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: :class:`tencentcloud.vm.v20200709.models.ImageResultsResultDetailLocation`
+        """
         return self._Location
 
     @Location.setter
@@ -1856,6 +2281,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def Label(self):
+        """标签
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -1864,6 +2293,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def LibId(self):
+        """库ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._LibId
 
     @LibId.setter
@@ -1872,6 +2305,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def LibName(self):
+        """库名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._LibName
 
     @LibName.setter
@@ -1880,6 +2317,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def Keywords(self):
+        """命中的关键词
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of str
+        """
         return self._Keywords
 
     @Keywords.setter
@@ -1888,6 +2329,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def Suggestion(self):
+        """建议
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -1896,6 +2341,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def Score(self):
+        """得分
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -1904,6 +2353,10 @@ class ImageResultsResultDetail(AbstractModel):
 
     @property
     def SubLabelCode(self):
+        """子标签码
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._SubLabelCode
 
     @SubLabelCode.setter
@@ -1965,6 +2418,10 @@ class ImageResultsResultDetailLocation(AbstractModel):
 
     @property
     def X(self):
+        """x坐标
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: float
+        """
         return self._X
 
     @X.setter
@@ -1973,6 +2430,10 @@ class ImageResultsResultDetailLocation(AbstractModel):
 
     @property
     def Y(self):
+        """y坐标
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: float
+        """
         return self._Y
 
     @Y.setter
@@ -1981,6 +2442,10 @@ class ImageResultsResultDetailLocation(AbstractModel):
 
     @property
     def Width(self):
+        """宽度
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Width
 
     @Width.setter
@@ -1989,6 +2454,10 @@ class ImageResultsResultDetailLocation(AbstractModel):
 
     @property
     def Height(self):
+        """高度
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Height
 
     @Height.setter
@@ -1997,6 +2466,10 @@ class ImageResultsResultDetailLocation(AbstractModel):
 
     @property
     def Rotate(self):
+        """旋转角度
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: float
+        """
         return self._Rotate
 
     @Rotate.setter
@@ -2039,6 +2512,11 @@ class ImageSegments(AbstractModel):
 
     @property
     def OffsetTime(self):
+        """截帧时间。
+点播文件：该值为相对于视频偏移时间，单位为秒，例如：0，5，10
+直播流：该值为时间戳，例如：1594650717
+        :rtype: str
+        """
         return self._OffsetTime
 
     @OffsetTime.setter
@@ -2047,6 +2525,9 @@ class ImageSegments(AbstractModel):
 
     @property
     def Result(self):
+        """画面截帧结果详情
+        :rtype: :class:`tencentcloud.vm.v20200709.models.ImageResult`
+        """
         return self._Result
 
     @Result.setter
@@ -2092,6 +2573,10 @@ class InputInfo(AbstractModel):
 
     @property
     def Type(self):
+        """传入的类型可选：URL，COS
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Type
 
     @Type.setter
@@ -2100,6 +2585,10 @@ class InputInfo(AbstractModel):
 
     @property
     def Url(self):
+        """Url地址
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Url
 
     @Url.setter
@@ -2108,6 +2597,10 @@ class InputInfo(AbstractModel):
 
     @property
     def BucketInfo(self):
+        """桶信息。当输入当时COS时，该字段不为空
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._BucketInfo
 
     @BucketInfo.setter
@@ -2153,6 +2646,9 @@ class MediaInfo(AbstractModel):
 
     @property
     def Codecs(self):
+        """编码格式
+        :rtype: str
+        """
         return self._Codecs
 
     @Codecs.setter
@@ -2161,6 +2657,10 @@ class MediaInfo(AbstractModel):
 
     @property
     def Duration(self):
+        """流检测时分片时长
+注意：此字段可能返回 0，表示取不到有效值。
+        :rtype: int
+        """
         return self._Duration
 
     @Duration.setter
@@ -2169,6 +2669,9 @@ class MediaInfo(AbstractModel):
 
     @property
     def Width(self):
+        """宽，单位为像素
+        :rtype: int
+        """
         return self._Width
 
     @Width.setter
@@ -2177,6 +2680,9 @@ class MediaInfo(AbstractModel):
 
     @property
     def Height(self):
+        """高，单位为像素
+        :rtype: int
+        """
         return self._Height
 
     @Height.setter
@@ -2228,6 +2734,9 @@ class MediaModerationConfig(AbstractModel):
 
     @property
     def UseOCR(self):
+        """是否使用OCR，默认为true
+        :rtype: bool
+        """
         return self._UseOCR
 
     @UseOCR.setter
@@ -2236,6 +2745,9 @@ class MediaModerationConfig(AbstractModel):
 
     @property
     def UseAudio(self):
+        """是否使用音频，默认为true。视频场景下，默认为 false
+        :rtype: bool
+        """
         return self._UseAudio
 
     @UseAudio.setter
@@ -2244,6 +2756,9 @@ class MediaModerationConfig(AbstractModel):
 
     @property
     def ImageFrequency(self):
+        """图片取帧频率, 单位（秒/帧），默认 5， 可选 1 ～ 300
+        :rtype: int
+        """
         return self._ImageFrequency
 
     @ImageFrequency.setter
@@ -2252,6 +2767,9 @@ class MediaModerationConfig(AbstractModel):
 
     @property
     def AudioFrequency(self):
+        """音频片段长度。单位为：秒
+        :rtype: int
+        """
         return self._AudioFrequency
 
     @AudioFrequency.setter
@@ -2260,6 +2778,9 @@ class MediaModerationConfig(AbstractModel):
 
     @property
     def SegmentOutput(self):
+        """临时文件存储位置
+        :rtype: :class:`tencentcloud.vm.v20200709.models.FileOutput`
+        """
         return self._SegmentOutput
 
     @SegmentOutput.setter
@@ -2268,6 +2789,9 @@ class MediaModerationConfig(AbstractModel):
 
     @property
     def CallbackUrl(self):
+        """回调地址
+        :rtype: str
+        """
         return self._CallbackUrl
 
     @CallbackUrl.setter
@@ -2329,6 +2853,9 @@ class Overview(AbstractModel):
 
     @property
     def TotalCount(self):
+        """总调用量
+        :rtype: int
+        """
         return self._TotalCount
 
     @TotalCount.setter
@@ -2337,6 +2864,9 @@ class Overview(AbstractModel):
 
     @property
     def TotalHour(self):
+        """总调用时长
+        :rtype: int
+        """
         return self._TotalHour
 
     @TotalHour.setter
@@ -2345,6 +2875,9 @@ class Overview(AbstractModel):
 
     @property
     def PassCount(self):
+        """通过量
+        :rtype: int
+        """
         return self._PassCount
 
     @PassCount.setter
@@ -2353,6 +2886,9 @@ class Overview(AbstractModel):
 
     @property
     def PassHour(self):
+        """通过时长
+        :rtype: int
+        """
         return self._PassHour
 
     @PassHour.setter
@@ -2361,6 +2897,9 @@ class Overview(AbstractModel):
 
     @property
     def EvilCount(self):
+        """违规量
+        :rtype: int
+        """
         return self._EvilCount
 
     @EvilCount.setter
@@ -2369,6 +2908,9 @@ class Overview(AbstractModel):
 
     @property
     def EvilHour(self):
+        """违规时长
+        :rtype: int
+        """
         return self._EvilHour
 
     @EvilHour.setter
@@ -2377,6 +2919,9 @@ class Overview(AbstractModel):
 
     @property
     def SuspectCount(self):
+        """疑似违规量
+        :rtype: int
+        """
         return self._SuspectCount
 
     @SuspectCount.setter
@@ -2385,6 +2930,9 @@ class Overview(AbstractModel):
 
     @property
     def SuspectHour(self):
+        """疑似违规时长
+        :rtype: int
+        """
         return self._SuspectHour
 
     @SuspectHour.setter
@@ -2433,6 +2981,11 @@ COS 腾讯云对象存储类型
 
     @property
     def Type(self):
+        """类型 可选：
+URL 资源链接类型
+COS 腾讯云对象存储类型
+        :rtype: str
+        """
         return self._Type
 
     @Type.setter
@@ -2441,6 +2994,9 @@ COS 腾讯云对象存储类型
 
     @property
     def Url(self):
+        """资源链接
+        :rtype: str
+        """
         return self._Url
 
     @Url.setter
@@ -2449,6 +3005,9 @@ COS 腾讯云对象存储类型
 
     @property
     def BucketInfo(self):
+        """腾讯云存储桶信息
+        :rtype: :class:`tencentcloud.vm.v20200709.models.BucketInfo`
+        """
         return self._BucketInfo
 
     @BucketInfo.setter
@@ -2492,6 +3051,9 @@ class TaskInput(AbstractModel):
 
     @property
     def DataId(self):
+        """数据ID
+        :rtype: str
+        """
         return self._DataId
 
     @DataId.setter
@@ -2500,6 +3062,9 @@ class TaskInput(AbstractModel):
 
     @property
     def Name(self):
+        """任务名
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -2508,6 +3073,9 @@ class TaskInput(AbstractModel):
 
     @property
     def Input(self):
+        """任务输入
+        :rtype: :class:`tencentcloud.vm.v20200709.models.StorageInfo`
+        """
         return self._Input
 
     @Input.setter
@@ -2564,6 +3132,17 @@ Block 确认违规
 
     @property
     def Label(self):
+        """命中的标签
+Porn 色情
+Sexy 性感
+Polity 政治
+Illegal 违法
+Abuse 谩骂
+Terror 暴恐
+Ad 广告
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -2572,6 +3151,13 @@ Block 确认违规
 
     @property
     def Suggestion(self):
+        """审核建议，可选值：
+Pass 通过，
+Review 建议人审，
+Block 确认违规
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -2580,6 +3166,10 @@ Block 确认违规
 
     @property
     def Score(self):
+        """得分，分数是 0 ～ 100
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -2628,6 +3218,10 @@ class TaskResult(AbstractModel):
 
     @property
     def DataId(self):
+        """请求时传入的DataId
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._DataId
 
     @DataId.setter
@@ -2636,6 +3230,10 @@ class TaskResult(AbstractModel):
 
     @property
     def TaskId(self):
+        """TaskId，任务ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -2644,6 +3242,10 @@ class TaskResult(AbstractModel):
 
     @property
     def Code(self):
+        """错误码。如果code为OK，则表示创建成功，其他则参考公共错误码
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Code
 
     @Code.setter
@@ -2652,6 +3254,10 @@ class TaskResult(AbstractModel):
 
     @property
     def Message(self):
+        """如果错误，该字段表示错误详情
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Message
 
     @Message.setter
@@ -2712,6 +3318,9 @@ class TrendCount(AbstractModel):
 
     @property
     def TotalCount(self):
+        """总调用量
+        :rtype: int
+        """
         return self._TotalCount
 
     @TotalCount.setter
@@ -2720,6 +3329,9 @@ class TrendCount(AbstractModel):
 
     @property
     def TotalHour(self):
+        """总调用时长
+        :rtype: int
+        """
         return self._TotalHour
 
     @TotalHour.setter
@@ -2728,6 +3340,9 @@ class TrendCount(AbstractModel):
 
     @property
     def PassCount(self):
+        """通过量
+        :rtype: int
+        """
         return self._PassCount
 
     @PassCount.setter
@@ -2736,6 +3351,9 @@ class TrendCount(AbstractModel):
 
     @property
     def PassHour(self):
+        """通过时长
+        :rtype: int
+        """
         return self._PassHour
 
     @PassHour.setter
@@ -2744,6 +3362,9 @@ class TrendCount(AbstractModel):
 
     @property
     def EvilCount(self):
+        """违规量
+        :rtype: int
+        """
         return self._EvilCount
 
     @EvilCount.setter
@@ -2752,6 +3373,9 @@ class TrendCount(AbstractModel):
 
     @property
     def EvilHour(self):
+        """违规时长
+        :rtype: int
+        """
         return self._EvilHour
 
     @EvilHour.setter
@@ -2760,6 +3384,9 @@ class TrendCount(AbstractModel):
 
     @property
     def SuspectCount(self):
+        """疑似违规量
+        :rtype: int
+        """
         return self._SuspectCount
 
     @SuspectCount.setter
@@ -2768,6 +3395,9 @@ class TrendCount(AbstractModel):
 
     @property
     def SuspectHour(self):
+        """疑似违规时长
+        :rtype: int
+        """
         return self._SuspectHour
 
     @SuspectHour.setter
@@ -2776,6 +3406,9 @@ class TrendCount(AbstractModel):
 
     @property
     def Date(self):
+        """日期
+        :rtype: str
+        """
         return self._Date
 
     @Date.setter
